#coding=utf8
from board import Board
from nabApi import NbaApi
import time
import locale
locale.setlocale(locale.LC_ALL, '')
api = NbaApi()
fresh_time = 30  #30s刷新一下

games = api.getGames()
last_updated = time.time()
status = "menu"

board = Board()
menus = []
board.draw_menu(games)
while(True):
    key = board.screen.getch()
    if key == ord('q'):
        break
    if key == ord('m'):
        status = "menu"
        games = api.getGames()
        board.draw_menu(games)
    elif status == 'menu':
        for idx in range(1,len(games)+1):
            if key == ord(str(idx)):
                status = 'live'
                msgs = api.getMessage(games[idx-1]['pb_url'])
                board.init_match(games[idx-1])
                board.update(msgs)
                last_updated = time.time()
                break
    elif status == 'live':
        t = time.time()
        if t - last_updated > fresh_time or key == ord("f"):
            msgs = api.getMessage(games[idx-1]['pb_url'])
            board.init_match(games[idx-1])
            board.update(msgs)
            last_updated = time.time()



from distutils.core import setup
import os

setup (
	name = "nbacli",
	version = "0.1",
	author = "chenminhua",
	author_email = "chenmh@shanghaitech.edu.cn",
	license = "GPL3",
	description = "watch nba in your cli, of course, no images and videos",
	url = "http://github.com/chenminhua/nba",
	packages = [
		'nba'
	],
	scripts = ['bin/nba'],
	install_requires = [
		
	]
)



#coding=utf8
import urllib2
from bs4 import BeautifulSoup
class NbaApi:
    def __init__(self):
        self.base_url = "http://g.hupu.com"
        self.home_url = 'http://g.hupu.com/nba'
        self.live_url = 'http://g.hupu.com/nba/daily/playbyplay_151581.html'

    def getGames(self):
        req = urllib2.Request(self.home_url)
        req.add_header('User-Agent', 'Mozilla/6.0 (iPhone; CPU iPhone OS 8_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/8.0 Mobile/10A5376e Safari/8536.25')
        text = urllib2.urlopen(req).read()
        soup = BeautifulSoup(text, 'html.parser')

        matches = soup.findAll('div', {"class":"team_vs"})
        playbacks = soup.findAll('div',{"class":"table_choose"})
        pb = []
        mat = []
        for playback in playbacks:
            pb.append(self.base_url + playback.find("a",{"class":"b"})['href'])

        for i,match in enumerate(matches):
            team1 = match.find('div', {"class":"team_vs_a_1"})
            team2 = match.find('div', {"class":"team_vs_a_2"})
            n1 = team1.find('span',{"class":"num"}).get_text()
            n2 = team2.find('span',{"class":"num"}).get_text()
            team1_name = team1.findAll('a')[1].get_text().encode('utf8', 'ignore')
            team2_name = team2.findAll('a')[1].get_text().encode('utf8', 'ignore')
            mat.append({"t_name1":team1_name,"t_name2":team2_name,
                        "n1":n1,"n2":n2,"pb_url":pb[i]
                        })
        return mat

    def getMessage(self, url):
        req = urllib2.Request(url)
        req.add_header('User-Agent', 'Mozilla/6.0 (iPhone; CPU iPhone OS 8_0 like Mac OS X) AppleWebKit/536.26 (KHTML, like Gecko) Version/8.0 Mobile/10A5376e Safari/8536.25')
        text = urllib2.urlopen(req).read()
        soup = BeautifulSoup(text, 'html.parser')

        msgs = []

        messages = soup.findAll("div",{"class":"table_list_live"})[1].findAll("tr")[-10:]
        for m in messages:
            me = m.findAll('td')

            time = me[0].get_text().encode('utf8', 'ignore')
            if len(me) == 1:
                msgs.append({"time":time,"team":"*","info":"*","score":"*"})
            else:
                team = me[1].get_text().encode('utf8', 'ignore')
                info = me[2].get_text().encode('utf8', 'ignore').strip()
                score = me[3].get_text()
                msgs.append({"time":time,"team":team,"info":info,"score":score})
        return msgs



#coding=utf8
import locale
locale.setlocale(locale.LC_ALL, '')
import curses
class Board:
    def __init__(self):
        self.screen = curses.initscr()
        curses.noecho()
        curses.cbreak()
        curses.curs_set(0)
        self.screen.keypad(1)
        self.screen.nodelay(1)
        curses.start_color()
        self.screen.refresh()
        curses.init_pair(1, curses.COLOR_WHITE, curses.COLOR_BLACK)
        curses.init_pair(2, curses.COLOR_GREEN, curses.COLOR_BLACK)

        self.cache_size = 10
        self.cache_lines = []

    def init_match(self, game):
        self.cache_lines = []
        self.screen.erase()
        self.draw_header(game["t_name1"],game["t_name2"])

    def draw_status(self, status):
        self.screen.addstr(0, 2, status, curses.color_pair(1))
        self.screen.refresh()

    def draw_menu(self, games):
        self.screen.erase()
        self.screen.addstr(1, 25, '近期比赛', curses.color_pair(2))
        x, y = 3, 2
        for i, g in enumerate(games):
            self.screen.addstr(x, y, '[%d]' % (i+1,), curses.color_pair(1))
            self.screen.addstr(x, y+5, g['t_name1'], curses.color_pair(1))
            self.screen.addstr(x, y+20, g['n1'], curses.color_pair(1))
            self.screen.addstr(x, y+30, g['n2'], curses.color_pair(1))
            self.screen.addstr(x, y+40, g['t_name2'], curses.color_pair(1))
            x += 2
        self.screen.refresh()

    def draw_header(self, home, away):
        teamstr = '主队: %s    客队: %s' % (home, away)
        self.screen.addstr(0, 5, teamstr, curses.color_pair(2))
        x, y = 2, 1
        self.screen.addstr(x, y, '本节剩余', curses.color_pair(2))
        self.screen.addstr(x, y+9, '当前比分', curses.color_pair(2))
        self.screen.addstr(x, y+19, '球队', curses.color_pair(2))
        self.screen.addstr(x, y+25, '比赛信息', curses.color_pair(2))

    def update(self, msgs):
        # if lines:
        #     if not self.cache_lines:
        #         self.cache_lines = lines[:self.cache_size]
        #     elif self.cache_lines[0][0] < lines[0][0]:
        #         self.update_cache(lines)

        x, y = 4, 2

        # if not self.cache_lines:
        #     self.screen.addstr(x, 10, '未开赛', curses.color_pair(1))
        #     self.screen.refresh()
        #     return
        for msg in msgs:
            self.screen.move(x, y)
            self.screen.clrtoeol()
            self.screen.addstr(x, y, msg["time"], curses.color_pair(1))
            self.screen.addstr(x, y+9, msg["score"], curses.color_pair(1))
            self.screen.addstr(x, y+18, msg["team"], curses.color_pair(1))
            self.screen.addstr(x, y+24, msg["info"], curses.color_pair(1))
            x += 1
            y = 2
        self.screen.refresh()
